@@ -1,24 +1,28 @@
 package DNS::Oterica::NodeFamily;
-our $VERSION = '0.092950';
-
-
+BEGIN {
+  $DNS::Oterica::NodeFamily::VERSION = '0.100000';
+}
 # ABSTRACT: a group of hosts that share common functions
 use Moose;
 
 
 has nodes => (
-  is  => 'ro',
   isa => 'ArrayRef',
-  auto_deref => 1,
   init_arg   => undef,
   default    => sub { [] },
+  traits   => [ 'Array' ],
+  handles  => {
+    nodes      => 'elements',
+    _push_node => 'push',
+  },
 );
 
 
 # XXX: do not allow dupes -- rjbs, 2009-09-11
 sub add_node {
   my ($self, $node) = @_;
-  push @{ $self->nodes }, $node;
+
+  $self->_push_node( $node );
 }
 
 
@@ -57,7 +61,7 @@ DNS::Oterica::NodeFamily - a group of hosts that share common functions
 
 =head1 VERSION
 
-version 0.092950
+version 0.100000
 
 =head1 ATTRIBUTES
 
@@ -65,10 +69,6 @@ version 0.092950
 
 This is an arrayref of the node objects that are in this family.
 
-=cut
-
-=pod
-
 =head2 hub
 
 This is the hub object into which the family was registered.
@@ -81,27 +81,19 @@ This is the hub object into which the family was registered.
 
 This adds the given node to the family.
 
-=cut
-
-=pod
-
 =head2 as_data_lines
 
 This method returns a list of lines of configuration.  By default it only
 generates begin and end marking comments.  This method is meant to be augmented
 by subclasses.
 
-=cut
-
-=pod
-
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
